@@ -38,7 +38,11 @@
 #include <io.h>
 #include <fcntl.h>
 
+#ifdef _WIN64
+#define PLATFORM "Win64"
+#else
 #define PLATFORM "Win32"
+#endif
 
 /* going away shortly... */
 #define HAVE_DRIVE_LETTERS
@@ -48,6 +52,7 @@
 #define APACHE_MPM_DIR  "server/mpm/winnt" /* generated on unix */
 
 #include <stddef.h>
+#include <stdlib.h> /* for exit() */
 
 #ifdef __cplusplus
 extern "C" {
@@ -84,7 +89,7 @@ typedef enum {
 
 FARPROC ap_load_dll_func(ap_dlltoken_e fnLib, char* fnName, int ordinal);
 
-PSECURITY_ATTRIBUTES GetNullACL();
+PSECURITY_ATTRIBUTES GetNullACL(void);
 void CleanNullACL(void *sa);
 
 int set_listeners_noninheritable(apr_pool_t *p);
@@ -93,7 +98,7 @@ int set_listeners_noninheritable(apr_pool_t *p);
 #define AP_DECLARE_LATE_DLL_FUNC(lib, rettype, calltype, fn, ord, args, names) \
     typedef rettype (calltype *ap_winapi_fpt_##fn) args; \
     static ap_winapi_fpt_##fn ap_winapi_pfn_##fn = NULL; \
-    __inline rettype ap_winapi_##fn args \
+    static APR_INLINE rettype ap_winapi_##fn args \
     {   if (!ap_winapi_pfn_##fn) \
             ap_winapi_pfn_##fn = (ap_winapi_fpt_##fn) ap_load_dll_func(lib, #fn, ord); \
         return (*(ap_winapi_pfn_##fn)) names; }; \
